ncpest objectsdncp(obj, ...)
## S3 method for class 'parncpt':
dncp(obj, fold=FALSE, ...)
## S3 method for class 'nparncpt':
dncp(obj, fold=FALSE, ...)
## S3 method for class 'sparncpt':
dncp(obj, fold=FALSE, ...)
## S3 method for class 'nparncpp':
dncp(obj, reflect=TRUE, ...)ncpest, from which noncentrality parameter density to be extractedTRUE, then the density of noncentrality paramters is folded about zero to give the density of absolute noncentrality parameters.TRUE, then the density of absolute noncentrality parameters is reflected about zero.parncpt. nparncpt ,sparncpt. nparncpp