pt approach.
For non-integer degrees of freedom, the polynomial interpolation is used to approximate the density.dt.int2(x, df, ncp, log = FALSE, ndiv = 8)TRUE, log densities are returned.df=0 and df=1,
and then iteratively computes the integral for larger df. For non-integer df, it uses ndiv nearest points to perform a
divided difference polynomial interpolation approximation. For integer df, this function is about 2 to 3 times faster than dt function and is exact.dtn.mix, dt, dt.lap, dt.sad, mTruncNorm