dt.lap(x, df, ncp = 0, log = FALSE, normalize = c("central",
"integral", "none"), ...)TRUE, log densities are returnedcentral, the normalization is such that the approxiamtion is exact when ncp=0.
If integral, numerical integration is performed such that the density integrate to 1 (not implemented yet).
If dt.int2, dt.sad, dt