dtn.mix(t, df, mu.ncp, sd.ncp, log = FALSE, approximation = c("int2",
"saddlepoint", "laplace", "none"), ...)TRUE, log density is returned.int2 computes exact denstiy for integer df and polynomially interpolate to non-integer degrees of freedom.
saddlepoint computes the saddle point approxdt(t/s, df, mu.ncp/s)/s where s=sqrt(1+sd.ncp*sd.ncp). But the various approximations are usually sufficient for large problems where speed is more important than precision.Young, G.A. and Smith R.L. (2005) Essentials of statistical inference. Cambridge University Press. Cambridge, UK.
Qu L, Nettleton D, Dekkers JCM. (2012) Improved Estimation of the Noncentrality Parameter Distribution from a Large Number of $t$-statistics, with Applications to False Discovery Rate Estimation in Microarray Data Analysis. Biometrics (in press).
dt.sad, dt.int2, dt.lap