logLik.ncpest: log likelihood from an object of class ncpest
Description
log likelihood from an object of class ncpest. This could be penalized liklihood in the case of a nparncpt object.
Usage
# S3 method for ncpest
logLik(object,...)
Arguments
object
the object of class ncpest
Value
an object of class logLik
Details
Extract the logLik component. This is used by AIC. The df is the estimated effetive number of parameters.