nparncpt(tstat, df, ...)
nparncpt.sqp(tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv'), lambdas=10^seq(-1,5,by=1),
starts, IC=c('BIC','CAIC','HQIC','AIC'), K=100, bounds=quantile(tstat,c(.01,.99)),
solver=c('solve.QP','lsei','ipop','LowRankQP'),plotit=FALSE, verbose=FALSE, approx.hess=TRUE, ... )1st.deriv) or second-order derivatives (2nd.deriv)
of the estimated density function of ncp. Note that only the first element is used.lambda to be tried. The one that minimizes NIC will be chosen.parncpt will be called with zeromean set to FALSE
to get an initial esimate of pi0. And the starting values (theta) will be set allAIC, BIC, CAIC, HQIC, specifying the factor multiplied to the ENP in computing Information Criterion (IC).ipop and kernlab are not very reliable. solve.QP is faster but lsei is more stable.plot.nparncpt should be called after estimation. This is always recommended before accepting the results.TRUE, extensive messages will be printed.TRUE,
for the kth Gaussian basis function and the gth tstat, the marginal t-statistic density evaluated dtn.mix. Usually, the approximation argument.c("nparncpt", "ncpest")logLik. The associated df is the estimated effective number of parameters (enp). The log likelihood is also penalized likelihood. See also logLik.ncpest and AIC.thetatstat and dflambdas that minimizes NIClambdas argument itselfnparncpt is a wrapper for nparncpt.sqp, the latter of which uses a sequential quadratic programming algorithm to find the mixing proportions
of the basis Gaussian density functions.parncpt, sparncpt,
fitted.nparncpt, plot.nparncpt, summary.nparncpt,
coef.ncpest, logLik.ncpest, vcov.ncpest,
AIC, dncpdata(simulatedTstat)
(npfit=nparncpt(tstat=simulatedTstat, df=8));
(pfit=parncpt(tstat=simulatedTstat, df=8, zeromean=FALSE)); plot(pfit)
(pfit0=parncpt(tstat=simulatedTstat, df=8, zeromean=TRUE)); plot(pfit0)
(spfit=sparncpt(npfit,pfit)); plot(spfit)Run the code above in your browser using DataLab