parncpt(tstat, df, zeromean = TRUE, ...)
parncpt.bfgs.0mean(tstat, df, starts, grids, approximation = "int2", ...)
parncpt.bfgs.non0mean(tstat, df, starts, grids, approximation = "int2", ...)
parncpt.momeff(tstat,n1,n2=n1,zeromean,gamma2,lower.df=6.1,upper.df=100,approx=TRUE)TRUE, then mean of noncentrality parameters is assumed to be zero and is not estimated.optimlower, upper, ngrid) defining the grids to be searched in find a good starting value.
Each component is a numeric vector of the same length as the number of parameters. lowerint2 is exact for integer df, but interpolate to fractional df.
'laplace' is the laplacian approximation; 'saddlepoint' is the saddlepoint approximation; 'none' computes the (sort of) exacclass attribute being c('parncpt', 'ncpest').tstat and dflogLik. Call logLik.ncpest to extract. Similarly, AIC is callable.coef.ncpest to extract.parncpt calls either parncpt.bfgs.0mean or parncpt.bfgs.non0mean, depending whether zeromean is TRUE or FALSE.
Both parncpt.bfgs.0mean and parncpt.bfgs.non0mean use the 'L-BFGS-B' algorithm by calling optim. All gradiants are analytical, but the Hessian is only numerical approximation.
The first parmater is always pi0, i.e., the proportion of true null hypotheses; the last parameter is always the standard deviation of noncentrality parameters;
for parncpt.bfgs.non0mean the middle parameter is the mean of noncentrality parameters, whereas for parncpt.bfgs.0mean the mean is set to 0 a priori.sparncpt, nparncpt,
fitted.parncpt, plot.parncpt, summary.parncpt,
coef.ncpest, logLik.ncpest, vcov.ncpest,
AIC, dncpdata(simulatedTstat)
(npfit=nparncpt(tstat=simulatedTstat, df=8));
(pfit=parncpt(tstat=simulatedTstat, df=8, zeromean=FALSE)); plot(pfit)
(pfit0=parncpt(tstat=simulatedTstat, df=8, zeromean=TRUE)); plot(pfit0)
(spfit=sparncpt(npfit,pfit)); plot(spfit)Run the code above in your browser using DataLab