subt(dat, n1 = round(ncol(dat)/2), n2 = ncol(dat) - n1,
f1method = c("lastbin", "qvalue"),
max.reps = if(balanced)20 else 5, balanced = FALSE, ...)n1 columns correspond to treatment group 1 and the rest n2
columns correspond to tInf, then all possible subsamples will be tried.
However, see Notes and the R arf1method.c("subt","matrix"), which is a G-by-3 numeric matrix, where G is nrow{dat},
with column names 'f1', 'n1', and 'n2', corresponding to the p-value density at 1 and subsample size
in each treatment group. This object also has the following attributes,n1.n2.f1method.max.reps.balanced.combn2R.
For each total subsample size M=3,4,...,N, where N=n1+n2, do the following,
balanced and m1=m2 is true, then do the following,
- 1.1
{Randomly choose max.reps subsamples among all possible subsamples by choosing m1 subjects from treatment group 1 and m2 subjects from treatment group 2, by using the function combn2R with sample.method="diff2" and try.rest=TURE. Note that this may not be always possible due to some pratical computational limitations. See combn2R for details.}
- 1.2
{For each subsample obtained in 1.1, (1) do a t-test for each gene (i.e., each row of the subsample), and (2) estimate the p-value density at one.}
}=m2<=n2>print.subt, plot.subt, extrp.pi0,
matrix.t.test,combn2R, subex, lastbin,
qvalueset.seed(9992722)
## this is how the 'simulatedDat' data set in this package generated
simulatedDat=sim.dat(G=5000)
## this is how the 'simulatedSubt' object in this package generated
simulatedSubt=subt(simulatedDat,balanced=FALSE,max.reps=Inf)
data(simulatedSubt)
print(simulatedSubt)Run the code above in your browser using DataLab